<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>S&apos;ha detectat un sistema autònom. Si us plau, seleccioneu la partició
arrel del sistema que voleu modificar (només es mostren
particions Linux)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Opcions </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Usa una estructura de menú simplificada sense submenús</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Usa un menú pla (sense submenús)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Arrenca com </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Es posa a &quot;0&quot; per arrencar inmediatament sense mostrar el menú, o a &quot;-1&quot; per esperar indefinidament.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Temps d&apos;espera del menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Paràmetres del kernel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>segons </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Amb aquesta opció activada qualsevol entrada que trieu del menú GRUB es desarà com l&apos;opció per omissió en futures arrencades</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Activa desar la darrera opció arrencada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Gestiona les opcions d&apos;arrencada UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Fons de pantalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Imatge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Activa el tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Pantalla de presentació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Vista prèvia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Missatges</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Molt detallats</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detallats (opció per omissió)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Limitats</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Mostra el registre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Still running</source>
        <translation>Encara executant-se</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation>El procés encara s&apos;està executant. Esteu segurs de voler sortir?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Set timeout</source>
        <translation>Defineix el temps d&apos;espera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Timeout in seconds:</source>
        <translation>Temps d&apos;espera en segons</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="435"/>
        <location filename="../mainwindow.cpp" line="1070"/>
        <source>Timeout: %1 seconds</source>
        <translation>Temps d&apos;espera %1 segons</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <location filename="../mainwindow.cpp" line="1085"/>
        <source>Boot Next: %1</source>
        <translation>Propera arrencada %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Removal confirmation</source>
        <translation>Elimina la confirmació</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Esteu segurs d&apos;esborrar aquesta entrada de l&apos;arrencada?
%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Select EFI file</source>
        <translation>Trieu el fitxer EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>Fitxers EFI (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <location filename="../mainwindow.cpp" line="325"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="518"/>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>No he trobat el punt de muntatge origen per %1 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Set name</source>
        <translation>Estableix el nom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Entreu el nom per a l&apos;ítem del menú UEFI: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Alguna cosa ha fallat, no puc afegir l&apos;entrada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Instal·lant la pantalla de presentació, espereu si us plau</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>Updating sources</source>
        <translation>Actualitzant les fonts</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Installing</source>
        <translation>Instal·lant</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Could not install the bootsplash.</source>
        <translation>No he pogut instal·lar la pantalla de presentació.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Boot Current: %1</source>
        <translation>Arrenca l&apos;actual: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>Cannot continue</source>
        <translation>No puc continuar</translation>
    </message>
    <message>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation type="vanished">No s&apos;ha seleccionat res, no puc canviar les opcions d&apos;arrencada. Sortint...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>Could not create a temporary folder</source>
        <translation>No s&apos;ha pogut crear un directori temporal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>No puc crear entorn chroot, no es poden canviar les opcions d&apos;arrencada. Sortint...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Alguna cosa ha fallat, no puc desar l&apos;ordre d&apos;arrencada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="795"/>
        <location filename="../mainwindow.cpp" line="1185"/>
        <source>Updating configuration, please wait</source>
        <translation>Actualitzant la configuració, espereu si us plau</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>Updating initramfs...</source>
        <translation>Actualitzant initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <location filename="../mainwindow.cpp" line="1197"/>
        <source>Updating grub...</source>
        <translation>Actualitzant GRUB...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>Done</source>
        <translation>Fet </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>Changes have been successfully applied.</source>
        <translation>S&apos;han aplicat els canvis amb èxit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="874"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="880"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="899"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">Quant a </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="877"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa per seleccionar les opcions d&apos;arrencada usuals</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Llicència</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registre de canvis</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancel·la</translation>
    </message>
    <message>
        <source>MX Boot Options</source>
        <translation type="vanished">MX Boot Options</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>Running in a Virtual Machine</source>
        <translation>Executant-se en Màquina Virtual</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="909"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>El vostre sistema actual s&apos;executa en una Màquina Virtual.
La pantalla de presentació Plymouth funcionarà de forma limitada, i tampoc podreu tenir vista prèvia del tema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="916"/>
        <source>Plymouth packages not installed</source>
        <translation>No s&apos;han instal·lat els paquets de Plymouth</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="917"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Els paquets de Plymouth no estan instal·lats.
Voleu continuar i instal·lar-los?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="939"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Imatges (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1043"/>
        <source>Press any key to close</source>
        <translation>Premeu qualsevol tecla per tancar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Log not found</source>
        <translation>No s&apos;ha trobat el registre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Could not find log at </source>
        <translation>No he trobat el registre a </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1051"/>
        <source>Edit UEFI Boot Entries</source>
        <translation>Edita les entrades d&apos;arrencada UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1058"/>
        <location filename="../mainwindow.cpp" line="1111"/>
        <source>Set ac&amp;tive</source>
        <translation>Defineix ac&amp;tiu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1059"/>
        <source>&amp;Add entry</source>
        <translation>&amp;Afegeix entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1060"/>
        <source>Boot &amp;next</source>
        <translation>Arrenca el &amp;següent</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1061"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1062"/>
        <source>Move &amp;down</source>
        <translation>Mou a&amp;vall</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1063"/>
        <source>&amp;Remove entry</source>
        <translation>T&amp;reu l&apos;entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1064"/>
        <source>Re&amp;set next</source>
        <translation>Re&amp;inicia el proper</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1065"/>
        <source>Change &amp;timeout</source>
        <translation>Canvia el &amp;temps d&apos;espera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>Move &amp;up</source>
        <translation>Mou am&amp;unt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <location filename="../mainwindow.cpp" line="1085"/>
        <source>not set, will boot using list order</source>
        <translation>no determinat, arrencarà usant l&apos;ordre de la llista</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1108"/>
        <source>Set &amp;inactive</source>
        <translation>Defineix &amp;inactiu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1161"/>
        <source>Needs reboot</source>
        <translation>Cal reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1162"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>S&apos;acaba d&apos;instal·lar Plymouth, cal reiniciar abans de poder mostrar la vista prèvia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1218"/>
        <source>Click to select theme</source>
        <translation>Cliqueu per triar el tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa per seleccionar les opcions d&apos;arrencada usuals</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembla que esteu connectat com a administrador, si us plau sortiu i connecteu-vos com a usuari normal per a usar aquest programa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="936"/>
        <source>Select image to display in bootloader</source>
        <translation>Trieu la imatge que es mostrarà a l&apos;arrencada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1228"/>
        <source>Select GRUB theme</source>
        <translation>Trieu el tema del GRUB</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
</context>
</TS>
